@@ -94,12 +94,9 @@ def main(model, n, verbose):
     root.bind('<Button-1>', start)
     root.mainloop()
     raw_data_json = json.dumps(recording)
-    logging.info(recording)
-    logging.info("Start evaluation...")
-    results = utils.classify_single_recording(raw_data_json,
-                                              model,
-                                              verbose)
-    show_results(results, n)
+    results = utils.evaluate_model_single_recording(model, raw_data_json)
+    import nntoolkit
+    nntoolkit.evaluate.show_results(results, n)
 
 
 if __name__ == '__main__':
